<img alt="trex Logo" src="https://cdn.berrysauce.me/assets/trex-banner.jpg">
<p align="center"><strong>Templatosaurus Rex: Create and manage project templates in your terminal 🦖</strong></p>
<p align="center">
    <img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/berrysauce/trex?label=size">
    <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/berrysauce/trex">
    <img alt="GitHub CodeQL" src="https://github.com/berrysauce/trex/actions/workflows/codeql-analysis.yml/badge.svg">
    <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/trex?label=PyPi%20downloads">
    <img alt="PyPI" src="https://img.shields.io/pypi/v/trex">
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/trex">
    <img alt="PyPI - Status" src="https://img.shields.io/pypi/status/trex">
</p>

---

## 🦖 What is trex?
trex is a template manager in the form of a CLI app. You can create, organize, and clone-from template directories. It doesn’t matter if the template is a directory on your machine or a GitHub repository: with trex you only need a few seconds to actually get to coding. Not only that, but trex is really easy to use.

## 🚧 Features and Roadmap
- [x] Organise templates (create, remove, list)
- [x] Make project from local directory template
- [ ] Make project from GitHub template  
- [x] Create git repository on creation
- [ ] Run scripts automatically on creation
- [ ] Create virtualenv automatically and import requirements on creation

→ Do you have any feature requests? [Submit them here](https://github.com/berrysauce/trex/issues).

## Install trex
**Make sure you have Python 3.9 or above installed on your system.**

trex is available on PyPi and can be installed via pip with the following command:
```
pip install trex
```
Check if the installation was successful:
```
trex version
```

## 📜 License

trex: A modern and intuitive templating CLI
Copyright (C) 2022 berrysauce (Paul Haedrich)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

For legal questions, contact legal[at]berrysauce[dot]me.

<a href="https://deta.sh/?ref=basketball" target="_blank"><img src="https://cdn.berrysauce.me/assets/deta-sponsor-banner.jpg" alt="Sponsored by Deta"></a>
